#
# spec file for package libtomcrypt
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2009 Exata T.I., Maringa, PR, Brasil.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         soname libtomcrypt0
Name:           libtomcrypt
Version:        1.17
Release:        lp151.2.3
Summary:        Cryptographic Toolkit Written in Portable C
License:        SUSE-Public-Domain
Group:          System/Libraries
Url:            http://libtom.org
Source0:        https://github.com/libtom/libtomcrypt/releases/download/%{version}/crypt-%{version}.tar.bz2
Source1:        https://github.com/libtom/libtomcrypt/releases/download/%{version}/crypt-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
Source3:        %{name}.changes
# PATCH-FIX-UPSTREAM libtomcrypt-makefile.shared.patch
Patch0:         %{name}-makefile.shared.patch
# PATCH-FIX-UPSTREAM https://github.com/libtom/libtomcrypt/pull/222
Patch1:         reproducible.patch
BuildRequires:  libtool
BuildRequires:  texlive-latex
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
LibTomCrypt is a fairly comprehensive, modular and portable cryptographic
toolkit that provides developers with a vast array of well known published
block ciphers, one-way hash functions, chaining modes, pseudo-random number
generators, public key cryptography and a plethora of other routines.


%package -n %{soname}
Summary:        Libraries for %{name}
Group:          System/Libraries

%description -n %{soname}
LibTomCrypt is a fairly comprehensive, modular and portable cryptographic
toolkit that provides developers with a vast array of well known published
block ciphers, one-way hash functions, chaining modes, pseudo-random
numbergenerators, public key cryptography and a plethora of other routines.

This package contains shared libraries

%package devel
Summary:        Development Files for LibTomCrypt
Group:          Development/Libraries/C and C++
Requires:       %{soname} = %{version}

%description devel
LibTomCrypt is a fairly comprehensive, modular and portable cryptographic
toolkit that provides developers with a vast array of well known published
block ciphers, one-way hash functions, chaining modes, pseudo-random
numbergenerators, public key cryptography and a plethora of other routines.

This package contains headers and other development files.


%package examples
Summary:        Example Files for LibTomCrypt
Group:          Development/Libraries/Other
Requires:       %{name}-devel = %{version}

%description examples
LibTomCrypt is a fairly comprehensive, modular and portable cryptographic
toolkit that provides developers with a vast array of well known published
block ciphers, one-way hash functions, chaining modes, pseudo-random
numbergenerators, public key cryptography and a plethora of other routines.

This package contains example *.c files showing how to use TomCrypt library.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{SOURCE3}")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
find .  -name '*.[ch]' | xargs sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g"

%build
export CFLAGS="%{optflags}"
make %{?_smp_mflags} LIBPATH=%{_libdir} -f makefile.shared

%install
make DESTDIR=%{buildroot} LIBPATH=%{_libdir} NODOCS=0 -f makefile.shared install
# Remove static libraries (It's upstream bug in makefile.shared I think.)
rm %{buildroot}%{_libdir}/*.a
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{soname} -p /sbin/ldconfig
%postun -n %{soname} -p /sbin/ldconfig

%files -n %{soname}
%defattr(-,root,root)
%{_libdir}/libtomcrypt.so.0
%{_libdir}/libtomcrypt.so.0.0.117
%{_libdir}/libtomcrypt_prof.so.0
%{_libdir}/libtomcrypt_prof.so.0.0.117
%doc LICENSE README TODO doc/crypt.pdf

%files devel
%defattr(-,root,root)
%attr(0644,root,root) %{_includedir}/tomcrypt*.h
%{_libdir}/libtomcrypt.so
%{_libdir}/libtomcrypt_prof.so

%files examples
%defattr(-,root,root)
%doc demos

%changelog
* Mon May 29 2017 bwiedemann@suse.com
- Add reproducible.patch to sort input files to make build reproducible
  (boo#1041090)
* Fri Feb 12 2016 mpluskal@suse.com
- Use url for source
- Add gpg signature
- Cleanup spec file with spec-cleaner
- Do not include build date/time
* Tue Jul 15 2014 darin@darins.net
- cleaned up with spec-cleaner
- examples now require the devel package
* Fri Jul 11 2014 darin@darins.net
- do not package libtool archives
* Thu Jul  3 2014 darin@darins.net
- fix requires due to rename
* Thu Jul  3 2014 darin@darins.net
- add group to libtomcrypt0 package
* Thu Jul  3 2014 darin@darins.net
- rename to libtomcrypt.{spec,changes} and the patch,
  there's not osc move|copy so I just cp'd them.
- update packaging for share-lib policy
- fix license
* Tue Jan 31 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
- Add libtool as BuildRequires for factory/12.2
* Thu Aug 12 2010 alexandre@exatati.com.br
- Spec file cleaned with spec-cleaner.
